@@ -1,12 +1,10 @@
-
 class Competition:
-
     def __init__(self, competitionName: str, competitionId: int):
         self.competitionName = competitionName.strip()
         self.competitionId = int(competitionId)
 
     def __repr__(self):
-        return f'{self.competitionName} ({self.competitionId})'
+        return f"{self.competitionName} ({self.competitionId})"
 
     def __str__(self):
         return self.__repr__()
